@@ -3,7 +3,7 @@ import logging
 from collections import namedtuple
 from time import time
 
-from .const import UpbCommand
+from .const import MINIMUM_BLINK_RATE, UpbCommand
 from .elements import Addr, Element, Elements
 from .message import (
     encode_activate_link,
@@ -79,6 +79,10 @@ class Link(Element):
 
     def blink(self, rate=-1):
         """(Helper) Blink a link."""
+        if rate < MINIMUM_BLINK_RATE and not self._pim.flags.get(
+            "unlimited_blink_rate"
+        ):
+            rate = MINIMUM_BLINK_RATE  # Force 1/3 of second blink rate
         self._pim.send(encode_blink(self._addr, rate), False)
         self.update_device_levels(UpbCommand.BLINK, 100)
 
@@ -123,7 +127,6 @@ class Links(Elements):
     def _levels(self, msg, upb_cmd, level=-1, rate=-1):
         if not msg.link:
             return
-        breakpoint()
         index = LinkAddr(msg.network_id, msg.dest_id).index
         link = self.elements.get(index)
         if not link:
